pub struct Linear { /* private fields */ }Expand description
Provides linear tasks execution.
Only one task might be executed at the time. The new task will be executed as soon as the previous one is finished.